Struct cerbero_lib::TicketCreds

source ·
pub struct TicketCreds {
    pub ticket_creds: Vec<TicketCred>,
}
Struct to store a vector of TicketCred with additional functionality

Fields

ticket_creds: Vec<TicketCred>

Implementations

source

impl TicketCreds

source

pub fn new(ticket_creds: Vec<TicketCred>) -> Self

source

pub fn empty() -> Self

source

pub fn as_bytes(&self) -> Vec<u8>

source

pub fn from_bytes(vec: Vec<u8>) -> Result<Self>

source

pub fn push(&mut self, ticket_info: TicketCred)

source

pub fn iter(&self) -> Iter<'_, TicketCred>

source

pub fn is_empty(&self) -> bool

source

pub fn get(&self, index: usize) -> Option<&TicketCred>

source

pub fn filter<P>(&self, predicate: P) -> Self
where P: Fn(&TicketCred) -> bool,

source

pub fn etype(&self, etype: i32) -> Self

Filter tickets for etype

source

pub fn prealm(&self, realm: &str) -> Self

Filter tickets for prealm (realm of the client). Case insensitive.

source

pub fn pname(&self, name: &PrincipalName) -> Self

Filter tickets for pname (the name of the client). Case insensitive.

source

pub fn srealm(&self, realm: &str) -> Self

Filter tickets for srealm (realm of the service). Case insensitive.

source

pub fn sname(&self, name: &PrincipalName) -> Self

Filter tickets for sname (the name of the service). Case insensitive.

source

pub fn user_realm(&self, realm: &str) -> Self

Filter tickets for user_realm. Same as prealm. Case insensitive.

source

pub fn username(&self, name: &str) -> Self

Filter for the username.

source

pub fn user(&self, user: &KrbUser) -> Self

Filter for the username and the user realm.

source

pub fn service_name(&self, name: &str) -> Self

Filter to only return tickets that includes a given name in service. It could be the name of the service (e.g: http, cifs), the hostname or any other string that appears in the service name. Case insensitive.

source

pub fn tgt(&self) -> Self

Filter to only returns TGTs.

source

pub fn tgt_realm(&self, realm: &str) -> Self

Filter to only returns TGTs for a given realm.

source

pub fn user_tgt_realm(&self, user: &KrbUser, realm: &str) -> Self

Filter to only returns TGTs for a given realm.

source

pub fn user_service( &self, client: &KrbUser, sname: &PrincipalName, srealm: &str, ) -> Self

Filter to return tickets for an user to an specific service

source

pub fn s4u2self_tgss( &self, user: &KrbUser, impersonate_user: &KrbUser, user_service: Option<&String>, ) -> Self

Returns the s4u2self tgss.